@@ -24,7 +24,6 @@ def Inicializar(n):
   Orden = 8
   Documento = ""
   return DatosList,Orden,Documento
-
 def search(symbolo):
   for c_element in DatosList:
     if c_element[0] == symbolo:
@@ -71,6 +70,8 @@ def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar qu
     #texto = texto.replace("text", Estilo)
 
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
+    print(Documento)
+    print(Documento + " /n"+str(texto))
     Documento = Documento + " /n"+str(texto)
 
   if Tipo == "Componente":#Si hemos identificado el elemento ingresado como un componente, entonces lo imprimimos en rojo
